<?php
/**
 * Implements hook_preprocess_HOOK() for maintenance-page.tpl.php.
 */
function nigraphic_preprocess_maintenance_page(&$variables) {
  // By default, site_name is set to Drupal if no db connection is available
  // or during site installation. Setting site_name to an empty string makes
  // the site and update pages look cleaner.
  // @see template_preprocess_maintenance_page
  if (!$variables['db_is_active']) {
    $variables['site_name'] = '';
  }
  drupal_add_css(drupal_get_path('theme', 'bartik') . '/css/maintenance-page.css');
}

/**
 * Implements hook_process_HOOK() for maintenance-page.tpl.php.
 */
function nigraphic_process_maintenance_page(&$variables) {
  $site_config = config('system.site');
  // Always print the site name and slogan, but if they are toggled off, we'll
  // just hide them visually.
  $variables['hide_site_name']   = theme_get_setting('toggle_name') ? FALSE : TRUE;
  $variables['hide_site_slogan'] = theme_get_setting('toggle_slogan') ? FALSE : TRUE;
  if ($variables['hide_site_name']) {
    // If toggle_name is FALSE, the site_name will be empty, so we rebuild it.
    $variables['site_name'] = check_plain($site_config->get('name'));
  }
  if ($variables['hide_site_slogan']) {
    // If toggle_site_slogan is FALSE, the site_slogan will be empty, so we rebuild it.
    $variables['site_slogan'] = filter_xss_admin($site_config->get('slogan'));
  }
}

/**
 * Implements hook_preprocess_HOOK() for block.tpl.php.
 */
function nigraphic_preprocess_block(&$variables) {
  // In the header and footer regions visually hide block titles.
  if ($variables['block']->region == 'header' 
  		|| $variables['block']->region == 'footer'
  		|| $variables['block']->region == 'search') {
    $variables['title_attributes']['class'][] = 'element-invisible';
  }
}


/**
 * Implements hook_preprocess_HOOK() for html.tpl.php.
 *
 * Adds body classes if certain regions have content.
 */
function nigraphic_preprocess_html(&$variables) {

  if (!empty($variables['page']['help'])
    || !empty($variables['page']['left'])
    || !empty($variables['page']['content'])
    || !empty($variables['page']['search'])
    || !empty($variables['page']['footer'])
    || !empty($variables['page']['topleft'])) {
    $variables['attributes']['class'][] = 'niregion';
  }
}
